{% load i18n %}
{% load wagtailadmin_tags %}

<div class="pagination" data-action-url="{{ choose_url }}">
    <p>{% blocktrans with page_num=items.number total_pages=items.paginator.num_pages %}Page {{ page_num }} of {{ total_pages }}.{% endblocktrans %}</p>
    <ul>
        <li class="prev">
            {% if items.has_previous %}
                <a href="#" data-page="{{ items.previous_page_number }}" class="icon icon-arrow-left">{% trans 'Previous' %}</a>
            {% endif %}
        </li>
        <li class="next">
            {% if items.has_next %}
                <a href="#" data-page="{{ items.next_page_number }}" class="icon icon-arrow-right-after">{% trans 'Next' %}</a>
            {% endif %}
        </li>
    </ul>
</div>
